@@ -1,7 +1,7 @@
 # Indicators
 ha_api_topics_req <- function(subcategory = NULL) {
   ha_req("topics") |>
-    httr2::req_url_query(limit = 20, subcategory = subcategory)
+    httr2::req_url_query(limit = 1000, subcategory = subcategory)
 }
 
 ha_api_categories_req <- function(name = NULL) {
@@ -11,13 +11,13 @@ ha_api_categories_req <- function(name = NULL) {
 
 ha_api_stratifications_req <- function() {
   ha_req("stratifications") |>
-    httr2::req_url_query(limit = 20)
+    httr2::req_url_query(limit = 1000)
 }
 
 ha_api_periods_req <- function(display = NULL) {
   ha_req("periods") |>
     httr2::req_url_path_append(display) |>
-    httr2::req_url_query(limit = 20)
+    httr2::req_url_query(limit = 1000)
 }
 
 # Places
@@ -27,7 +27,8 @@ ha_api_layers_req <- function() {
 
 ha_api_geographies_req <- function(layer_slug) {
   ha_req("geographies") |>
-    httr2::req_url_path_append(layer_slug)
+    httr2::req_url_path_append(layer_slug) |>
+    httr2::req_url_query(limit = 1000)
 }
 
 ha_api_points_req <- function(uuid = NULL) {
@@ -50,7 +51,7 @@ ha_api_coverage_req <- function(topic, layers = NULL) {
 ha_api_data_req <- function(topic, population, period, layer) {
   ha_req("data") |>
     httr2::req_url_query(
-      topic =  topic,
+      topic = topic,
       population = population,
       period = period,
       layer = layer,
